==> haskell-boundedchan-1.0.3.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boundedchan.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 BoundedChan
version:              1.0.3.0
visibility:           public
id:                   BoundedChan-1.0.3.0-Bevv2q2rRnjAUZpH50Qt9K
key:                  BoundedChan-1.0.3.0-Bevv2q2rRnjAUZpH50Qt9K
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@galois.com>
author:
    Adam Wick <awick@galois.com>, Chris Kuklewicz <haskell@list.mightyreason.com>, Paul Hendry

stability:            stable
synopsis:             Implementation of bounded channels.
description:
    This library introduces BoundedChan. BoundedChans differ from
    Chans in that they are guaranteed to contain no more than a
    certain number of elements.

category:             Concurrency
abi:                  e1762a48c8eb5087775abf564441eac2
exposed:              True
exposed-modules:      Control.Concurrent.BoundedChan
import-dirs:          /usr/lib/ghc-9.0.2/site-local/BoundedChan-1.0.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/BoundedChan-1.0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boundedchan
hs-libraries:         HSBoundedChan-1.0.3.0-Bevv2q2rRnjAUZpH50Qt9K
depends:              array-0.5.4.0 base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-boundedchan/html/BoundedChan.haddock
haddock-html:         /usr/share/doc/haskell-boundedchan/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-boundedchan-1.0.3.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boundedchan.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 BoundedChan
version:              1.0.3.0
visibility:           public
id:                   BoundedChan-1.0.3.0-GASw0jI0hsI8wIs0B8SAkA
key:                  BoundedChan-1.0.3.0-GASw0jI0hsI8wIs0B8SAkA
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@galois.com>
author:
    Adam Wick <awick@galois.com>, Chris Kuklewicz <haskell@list.mightyreason.com>, Paul Hendry

stability:            stable
synopsis:             Implementation of bounded channels.
description:
    This library introduces BoundedChan. BoundedChans differ from
    Chans in that they are guaranteed to contain no more than a
    certain number of elements.

category:             Concurrency
abi:                  fb1144f02a82c9a7ef9d93171b10e060
exposed:              True
exposed-modules:      Control.Concurrent.BoundedChan
import-dirs:          /usr/lib/ghc-9.2.8/site-local/BoundedChan-1.0.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/BoundedChan-1.0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boundedchan
hs-libraries:         HSBoundedChan-1.0.3.0-GASw0jI0hsI8wIs0B8SAkA
depends:              array-0.5.4.0 base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-boundedchan/html/BoundedChan.haddock
haddock-html:         /usr/share/doc/haskell-boundedchan/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
